Minimize
--------

.. todo:: Fill overview page

.. todo:: Maybe group minimizer Strategies?

.. autosummary::
    :toctree: minimize

    zfit.minimize.WrapOptimizer
    zfit.minimize.Adam
    zfit.minimize.Minuit
    zfit.minimize.Scipy
    zfit.minimize.BFGS
    zfit.minimize.DefaultStrategy
    zfit.minimize.DefaultToyStrategy
    zfit.minimizers.baseminimizer.PushbackStrategy
    zfit.minimize.FitResult
